@@ -13,14 +13,12 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
-import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_67de8e8d
-import aws_cdk.aws_iam as _aws_cdk_aws_iam_940a1ce0
-import aws_cdk.core as _aws_cdk_core_f4b25747
-import managed_instance_role as _managed_instance_role_4b8364e6
+import aws_cdk.aws_ec2
+import aws_cdk.aws_iam
+import constructs
+import managed_instance_role
 
 
 @jsii.data_type(
@@ -41,12 +39,7 @@ class AmiLookup:
         :param owners: The owners to use for AMI lookup.
         :param windows: Is this AMI expected to be windows?
         '''
-        if __debug__:
-            type_hints = typing.get_type_hints(_typecheckingstub__d674b560bd4bc3b219af3059fb55b7053e071d77d2616667b61f7350765bfec0)
-            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
-            check_type(argname="argument owners", value=owners, expected_type=type_hints["owners"])
-            check_type(argname="argument windows", value=windows, expected_type=type_hints["windows"])
-        self._values: typing.Dict[builtins.str, typing.Any] = {
+        self._values: typing.Dict[str, typing.Any] = {
             "name": name,
         }
         if owners is not None:
@@ -86,25 +79,25 @@ class AmiLookup:
 
 
 class InstanceService(
-    _aws_cdk_core_f4b25747.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@renovosolutions/cdk-library-renovo-instance-service.InstanceService",
 ):
     def __init__(
         self,
-        scope: _aws_cdk_core_f4b25747.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
-        ami: _aws_cdk_aws_ec2_67de8e8d.IMachineImage,
+        ami: aws_cdk.aws_ec2.IMachineImage,
         name: builtins.str,
-        vpc: _aws_cdk_aws_ec2_67de8e8d.Vpc,
+        vpc: aws_cdk.aws_ec2.Vpc,
         allow_all_outbound: typing.Optional[builtins.bool] = None,
         disable_inline_rules: typing.Optional[builtins.bool] = None,
         enable_cloudwatch_logs: typing.Optional[builtins.bool] = None,
         enabled_no_public_ingress_aspect: typing.Optional[builtins.bool] = None,
         enable_no_db_ports_aspect: typing.Optional[builtins.bool] = None,
         enable_no_remote_management_ports_aspect: typing.Optional[builtins.bool] = None,
-        subnet_type: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.SubnetType] = None,
+        subnet_type: typing.Optional[aws_cdk.aws_ec2.SubnetType] = None,
     ) -> None:
         '''
         :param scope: -
@@ -120,10 +113,6 @@ class InstanceService(
         :param enable_no_remote_management_ports_aspect: Whether or not to prevent security group from containing rules that allow access to remote management ports: SSH, RDP, WinRM, WinRM over HTTPs. If these ports are opened when this is enabled an error will be added to CDK metadata and deployment and synth will fail. Default: true
         :param subnet_type: The subnet type to launch this service in. Default: ec2.SubnetType.PRIVATE
         '''
-        if __debug__:
-            type_hints = typing.get_type_hints(_typecheckingstub__2e6c6165f88cb76812d03df20762f2a821c24946119dadf31bbfc7466fdb9554)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = InstanceServiceProps(
             ami=ami,
             name=name,
@@ -139,15 +128,15 @@ class InstanceService(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="instanceProfile")
-    def instance_profile(self) -> _managed_instance_role_4b8364e6.ManagedInstanceRole:
-        return typing.cast(_managed_instance_role_4b8364e6.ManagedInstanceRole, jsii.get(self, "instanceProfile"))
+    def instance_profile(self) -> managed_instance_role.ManagedInstanceRole:
+        return typing.cast(managed_instance_role.ManagedInstanceRole, jsii.get(self, "instanceProfile"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="securityGroup")
-    def security_group(self) -> _aws_cdk_aws_ec2_67de8e8d.SecurityGroup:
-        return typing.cast(_aws_cdk_aws_ec2_67de8e8d.SecurityGroup, jsii.get(self, "securityGroup"))
+    def security_group(self) -> aws_cdk.aws_ec2.SecurityGroup:
+        return typing.cast(aws_cdk.aws_ec2.SecurityGroup, jsii.get(self, "securityGroup"))
 
 
 @jsii.data_type(
@@ -170,16 +159,16 @@ class InstanceServiceProps:
     def __init__(
         self,
         *,
-        ami: _aws_cdk_aws_ec2_67de8e8d.IMachineImage,
+        ami: aws_cdk.aws_ec2.IMachineImage,
         name: builtins.str,
-        vpc: _aws_cdk_aws_ec2_67de8e8d.Vpc,
+        vpc: aws_cdk.aws_ec2.Vpc,
         allow_all_outbound: typing.Optional[builtins.bool] = None,
         disable_inline_rules: typing.Optional[builtins.bool] = None,
         enable_cloudwatch_logs: typing.Optional[builtins.bool] = None,
         enabled_no_public_ingress_aspect: typing.Optional[builtins.bool] = None,
         enable_no_db_ports_aspect: typing.Optional[builtins.bool] = None,
         enable_no_remote_management_ports_aspect: typing.Optional[builtins.bool] = None,
-        subnet_type: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.SubnetType] = None,
+        subnet_type: typing.Optional[aws_cdk.aws_ec2.SubnetType] = None,
     ) -> None:
         '''
         :param ami: The Amazon Machine Image (AMI) to launch the target instance with.
@@ -193,19 +182,7 @@ class InstanceServiceProps:
         :param enable_no_remote_management_ports_aspect: Whether or not to prevent security group from containing rules that allow access to remote management ports: SSH, RDP, WinRM, WinRM over HTTPs. If these ports are opened when this is enabled an error will be added to CDK metadata and deployment and synth will fail. Default: true
         :param subnet_type: The subnet type to launch this service in. Default: ec2.SubnetType.PRIVATE
         '''
-        if __debug__:
-            type_hints = typing.get_type_hints(_typecheckingstub__adbc60907b40e52c2f3ec1be03a20c5e4e957d8d8b7ae22fe0df279277b9f20e)
-            check_type(argname="argument ami", value=ami, expected_type=type_hints["ami"])
-            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
-            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
-            check_type(argname="argument allow_all_outbound", value=allow_all_outbound, expected_type=type_hints["allow_all_outbound"])
-            check_type(argname="argument disable_inline_rules", value=disable_inline_rules, expected_type=type_hints["disable_inline_rules"])
-            check_type(argname="argument enable_cloudwatch_logs", value=enable_cloudwatch_logs, expected_type=type_hints["enable_cloudwatch_logs"])
-            check_type(argname="argument enabled_no_public_ingress_aspect", value=enabled_no_public_ingress_aspect, expected_type=type_hints["enabled_no_public_ingress_aspect"])
-            check_type(argname="argument enable_no_db_ports_aspect", value=enable_no_db_ports_aspect, expected_type=type_hints["enable_no_db_ports_aspect"])
-            check_type(argname="argument enable_no_remote_management_ports_aspect", value=enable_no_remote_management_ports_aspect, expected_type=type_hints["enable_no_remote_management_ports_aspect"])
-            check_type(argname="argument subnet_type", value=subnet_type, expected_type=type_hints["subnet_type"])
-        self._values: typing.Dict[builtins.str, typing.Any] = {
+        self._values: typing.Dict[str, typing.Any] = {
             "ami": ami,
             "name": name,
             "vpc": vpc,
@@ -226,11 +203,11 @@ class InstanceServiceProps:
             self._values["subnet_type"] = subnet_type
 
     @builtins.property
-    def ami(self) -> _aws_cdk_aws_ec2_67de8e8d.IMachineImage:
+    def ami(self) -> aws_cdk.aws_ec2.IMachineImage:
         '''The Amazon Machine Image (AMI) to launch the target instance with.'''
         result = self._values.get("ami")
         assert result is not None, "Required property 'ami' is missing"
-        return typing.cast(_aws_cdk_aws_ec2_67de8e8d.IMachineImage, result)
+        return typing.cast(aws_cdk.aws_ec2.IMachineImage, result)
 
     @builtins.property
     def name(self) -> builtins.str:
@@ -240,11 +217,11 @@ class InstanceServiceProps:
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def vpc(self) -> _aws_cdk_aws_ec2_67de8e8d.Vpc:
+    def vpc(self) -> aws_cdk.aws_ec2.Vpc:
         '''The VPC to launch this service in.'''
         result = self._values.get("vpc")
         assert result is not None, "Required property 'vpc' is missing"
-        return typing.cast(_aws_cdk_aws_ec2_67de8e8d.Vpc, result)
+        return typing.cast(aws_cdk.aws_ec2.Vpc, result)
 
     @builtins.property
     def allow_all_outbound(self) -> typing.Optional[builtins.bool]:
@@ -314,13 +291,13 @@ class InstanceServiceProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def subnet_type(self) -> typing.Optional[_aws_cdk_aws_ec2_67de8e8d.SubnetType]:
+    def subnet_type(self) -> typing.Optional[aws_cdk.aws_ec2.SubnetType]:
         '''The subnet type to launch this service in.
 
         :default: ec2.SubnetType.PRIVATE
         '''
         result = self._values.get("subnet_type")
-        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_67de8e8d.SubnetType], result)
+        return typing.cast(typing.Optional[aws_cdk.aws_ec2.SubnetType], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -335,13 +312,13 @@ class InstanceServiceProps:
 
 
 class ManagedLoggingPolicy(
-    _aws_cdk_core_f4b25747.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@renovosolutions/cdk-library-renovo-instance-service.ManagedLoggingPolicy",
 ):
     def __init__(
         self,
-        scope: _aws_cdk_core_f4b25747.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         os: builtins.str,
@@ -351,18 +328,14 @@ class ManagedLoggingPolicy(
         :param id: -
         :param os: The OS of the instance this policy is for.
         '''
-        if __debug__:
-            type_hints = typing.get_type_hints(_typecheckingstub__250d7a80abe744f451727d097168e90e5802e7cb034a4e371bc6601984c73958)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ManagedLoggingPolicyProps(os=os)
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="policy")
-    def policy(self) -> _aws_cdk_aws_iam_940a1ce0.ManagedPolicy:
-        return typing.cast(_aws_cdk_aws_iam_940a1ce0.ManagedPolicy, jsii.get(self, "policy"))
+    def policy(self) -> aws_cdk.aws_iam.ManagedPolicy:
+        return typing.cast(aws_cdk.aws_iam.ManagedPolicy, jsii.get(self, "policy"))
 
 
 @jsii.data_type(
@@ -375,10 +348,7 @@ class ManagedLoggingPolicyProps:
         '''
         :param os: The OS of the instance this policy is for.
         '''
-        if __debug__:
-            type_hints = typing.get_type_hints(_typecheckingstub__766f3013b3bbcda5f0bc028c1a68c40993ebe6321cf668f202d748fcec7df730)
-            check_type(argname="argument os", value=os, expected_type=type_hints["os"])
-        self._values: typing.Dict[builtins.str, typing.Any] = {
+        self._values: typing.Dict[str, typing.Any] = {
             "os": os,
         }
 
@@ -410,62 +380,3 @@ __all__ = [
 ]
 
 publication.publish()
-
-def _typecheckingstub__d674b560bd4bc3b219af3059fb55b7053e071d77d2616667b61f7350765bfec0(
-    *,
-    name: builtins.str,
-    owners: typing.Optional[typing.Sequence[builtins.str]] = None,
-    windows: typing.Optional[builtins.bool] = None,
-) -> None:
-    """Type checking stubs"""
-    pass
-
-def _typecheckingstub__2e6c6165f88cb76812d03df20762f2a821c24946119dadf31bbfc7466fdb9554(
-    scope: _aws_cdk_core_f4b25747.Construct,
-    id: builtins.str,
-    *,
-    ami: _aws_cdk_aws_ec2_67de8e8d.IMachineImage,
-    name: builtins.str,
-    vpc: _aws_cdk_aws_ec2_67de8e8d.Vpc,
-    allow_all_outbound: typing.Optional[builtins.bool] = None,
-    disable_inline_rules: typing.Optional[builtins.bool] = None,
-    enable_cloudwatch_logs: typing.Optional[builtins.bool] = None,
-    enabled_no_public_ingress_aspect: typing.Optional[builtins.bool] = None,
-    enable_no_db_ports_aspect: typing.Optional[builtins.bool] = None,
-    enable_no_remote_management_ports_aspect: typing.Optional[builtins.bool] = None,
-    subnet_type: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.SubnetType] = None,
-) -> None:
-    """Type checking stubs"""
-    pass
-
-def _typecheckingstub__adbc60907b40e52c2f3ec1be03a20c5e4e957d8d8b7ae22fe0df279277b9f20e(
-    *,
-    ami: _aws_cdk_aws_ec2_67de8e8d.IMachineImage,
-    name: builtins.str,
-    vpc: _aws_cdk_aws_ec2_67de8e8d.Vpc,
-    allow_all_outbound: typing.Optional[builtins.bool] = None,
-    disable_inline_rules: typing.Optional[builtins.bool] = None,
-    enable_cloudwatch_logs: typing.Optional[builtins.bool] = None,
-    enabled_no_public_ingress_aspect: typing.Optional[builtins.bool] = None,
-    enable_no_db_ports_aspect: typing.Optional[builtins.bool] = None,
-    enable_no_remote_management_ports_aspect: typing.Optional[builtins.bool] = None,
-    subnet_type: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.SubnetType] = None,
-) -> None:
-    """Type checking stubs"""
-    pass
-
-def _typecheckingstub__250d7a80abe744f451727d097168e90e5802e7cb034a4e371bc6601984c73958(
-    scope: _aws_cdk_core_f4b25747.Construct,
-    id: builtins.str,
-    *,
-    os: builtins.str,
-) -> None:
-    """Type checking stubs"""
-    pass
-
-def _typecheckingstub__766f3013b3bbcda5f0bc028c1a68c40993ebe6321cf668f202d748fcec7df730(
-    *,
-    os: builtins.str,
-) -> None:
-    """Type checking stubs"""
-    pass
