@@ -8,21 +8,16 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 import aspects-security-group._jsii
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.cloud_assembly_schema._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 import managed_instance_role._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@renovosolutions/cdk-library-renovo-instance-service",
-    "1.0.325",
+    "2.1.8",
     __name__[0:-6],
-    "cdk-library-renovo-instance-service@1.0.325.jsii.tgz",
+    "cdk-library-renovo-instance-service@2.1.8.jsii.tgz",
 )
 
 __all__ = [
